# This script uses AutoDock Vina to dock tetracycline to a receptor.
# You can use the mutation Jupyter notebook first to mutate your protein and prepare it for the docking
# by creating a .pdbqt file.

from vina import Vina
import os

# This script expects a directory 'PDBQT_files' in which all mutated receptors (TetR dimer) are stored.
# Tetracycline is then docked to each mutated receptor
# and the docking affintiy stored in the file 'binding_affinities.txt'

directory = 'PDBQT_files'
for filename in os.listdir(directory):
    path = os.path.join(directory, filename)

    v = Vina(sf_name='vina')
    v.set_receptor(path)
    print("Receptor set!")
    v.set_ligand_from_file('tetra_3D_openbabbel.pdbqt')
    print("Ligand set!")
    #Specify the center of the approx. target docking position
    v.compute_vina_maps(center=[15.917, -2.405, -1.171], box_size=[40, 40, 40])
    print("Computed Vina maps!")

    # Score the current pose
    energy = v.score()
    print('Score before minimization: %.3f (kcal/mol)' % energy[0])

    # Minimized locally the current pose
    energy_minimized = v.optimize()
    print('Score after minimization : %.3f (kcal/mol)' % energy_minimized[0])

    # Dock the ligand
    v.dock(exhaustiveness=32, n_poses=25)
    final_energy = v.score()
    print('Final Score: %.3f (kcal/mol)' % final_energy[0])

    #Store final binding affinity in the 'binding_affinities.txt' files
    file = open("binding_affinities.txt", "a")  # append mode
    file.write(f'{filename.split(".")[0]}:' + '%.3f' % final_energy[0])
    file.close()

    #save the AutoDock binding position
    v.write_poses(f'output/{filename.split(".")[0]}.pdbqt', n_poses=5, overwrite=True)
